@@ -12,7 +12,7 @@ pub struct FillEvent {
     pub event_type: &'static str,
     pub trace_id: Uuid,
     pub timestamp: DateTime<Utc>,
-    pub exchange: String,
+    pub exchange: &'static str,
     pub symbol: String,
     pub market_meta: MarketMeta, // Metadata propagated from source MarketEvent
     pub decision: Decision,      // LONG, CloseLong, SHORT or CloseShort
@@ -27,7 +27,7 @@ impl Default for FillEvent {
             event_type: FillEvent::EVENT_TYPE,
             trace_id: Uuid::new_v4(),
             timestamp: Utc::now(),
-            exchange: String::from("BINANCE"),
+            exchange: "Binance",
             symbol: String::from("ETH-USD"),
             market_meta: Default::default(),
             decision: Decision::default(),
@@ -73,7 +73,7 @@ pub type FeeAmount = f64;
 pub struct FillEventBuilder {
     pub trace_id: Option<Uuid>,
     pub timestamp: Option<DateTime<Utc>>,
-    pub exchange: Option<String>,
+    pub exchange: Option<&'static str>,
     pub symbol: Option<String>,
     pub market_meta: Option<MarketMeta>,
     pub decision: Option<Decision>,
@@ -101,14 +101,14 @@ impl FillEventBuilder {
         }
     }
 
-    pub fn exchange(self, value: String) -> Self {
+    pub fn exchange(self, value: &'static str) -> Self {
         Self {
             exchange: Some(value),
             ..self
         }
     }
 
-    pub fn symbol(self, value: String) -> Self {
+    pub fn symbol(self, value: &'static str) -> Self {
         Self {
             exchange: Some(value),
             ..self
